/**
 * Copyright (c) 2008-2011 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://www.sonatype.com/products/nexus/attributions.
 *
 * This program is free software: you can redistribute it and/or modify it only under the terms of the GNU Affero General
 * Public License Version 3 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License Version 3
 * for more details.
 *
 * You should have received a copy of the GNU Affero General Public License Version 3 along with this program.  If not, see
 * http://www.gnu.org/licenses.
 *
 * Sonatype Nexus (TM) Open Source Version is available from Sonatype, Inc. Sonatype and Sonatype Nexus are trademarks of
 * Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation. M2Eclipse is a trademark of the Eclipse Foundation.
 * All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.proxy.router;

import org.sonatype.nexus.configuration.Configurable;
import org.sonatype.nexus.proxy.AccessDeniedException;
import org.sonatype.nexus.proxy.IllegalOperationException;
import org.sonatype.nexus.proxy.ItemNotFoundException;
import org.sonatype.nexus.proxy.RepositoryNotAvailableException;
import org.sonatype.nexus.proxy.ResourceStore;
import org.sonatype.nexus.proxy.ResourceStoreRequest;
import org.sonatype.nexus.proxy.StorageException;
import org.sonatype.nexus.proxy.access.Action;
import org.sonatype.nexus.proxy.item.StorageItem;
import org.sonatype.nexus.proxy.item.StorageLinkItem;
import org.sonatype.nexus.proxy.registry.RepositoryRegistry;
import org.sonatype.nexus.proxy.repository.Repository;

/**
 * The Repository Router interface. This router offers a simple API to request items from Proximity. It calculates and
 * knows which repositories are registered within Proximity.
 * 
 * @see Repository
 * @see RepositoryRegistry
 * @author cstamas
 */
public interface RepositoryRouter
    extends ResourceStore, Configurable
{
    boolean isFollowLinks();

    void setFollowLinks( boolean follow );

    /**
     * Dereferences the link.
     * 
     * @param item
     * @return
     * @throws AccessDeniedException
     * @throws ItemNotFoundException
     * @throws RepositoryNotAvailableException
     * @throws StorageException
     */
    StorageItem dereferenceLink( StorageLinkItem link )
        throws AccessDeniedException,
            ItemNotFoundException,
            IllegalOperationException,
            StorageException;

    /**
     * Dereferences the link.
     * 
     * @param item
     * @param localOnly
     * @param remoteOnly
     * @return
     * @throws AccessDeniedException
     * @throws ItemNotFoundException
     * @throws RepositoryNotAvailableException
     * @throws StorageException
     */
    StorageItem dereferenceLink( StorageLinkItem link, boolean localOnly, boolean remoteOnly )
        throws AccessDeniedException,
            ItemNotFoundException,
            IllegalOperationException,
            StorageException;

    /**
     * Calculates the RequestRoute for the given request.
     * 
     * @param request
     * @return
     * @throws ItemNotFoundException
     */
    RequestRoute getRequestRouteForRequest( ResourceStoreRequest request )
        throws ItemNotFoundException;
    
    /**
     * Authorizes a TargetSet against an action. Used by authz filter to check the incoming request, that is obviously
     * addressed to content root.
     * 
     * @param repository
     * @param path
     * @return
     */
    boolean authorizePath( ResourceStoreRequest request, Action action );
    
}
